@@ -1,6 +1,6 @@
 
 from .portfolio import Portfolio, OptimizedPortfolio
-from .dynamic import DynamicPortfolio, InsufficientSharesException
+from .dynamic import DynamicPortfolio, DynamicPortfolioWithDividends, InsufficientSharesException
 from .create import get_optimized_portfolio_on_sharpe_ratio, get_optimized_portfolio_on_mpt_costfunction, \
     get_optimized_portfolio_on_mpt_entropy_costfunction
 from .optimize.numerics import get_BlackScholesMerton_stocks_estimation
